.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.docs_resolv
==========================

.. automodule:: sphinx_gallery.docs_resolv

   
   

   Functions
   ---------

   

   .. autofunction:: embed_code_links

   .. include:: backreferences/sphinx_gallery.docs_resolv.embed_code_links.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: get_data

   .. include:: backreferences/sphinx_gallery.docs_resolv.get_data.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: parse_sphinx_docopts

   .. include:: backreferences/sphinx_gallery.docs_resolv.parse_sphinx_docopts.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>
   
   

   
   

   Classes
   -------

   
   .. autoclass:: SphinxDocLinkResolver
      :members:

   .. include:: backreferences/sphinx_gallery.docs_resolv.SphinxDocLinkResolver.examples

   .. raw:: html

      <div class="sphx-glr-clear"></div>
   
   

   
   
   